package com.xinda.itsm.service;

import java.util.List;
import com.xinda.itsm.domain.Schedule;

/**
 * 调度计划管理Service接口
 * 
 * @author kerwincui
 * @date 2025-04-23
 */
public interface IScheduleService 
{
    /**
     * 查询调度计划管理
     * 
     * @param scheduleId 调度计划管理主键
     * @return 调度计划管理
     */
    public Schedule selectScheduleByScheduleId(Long scheduleId);

    /**
     * 查询调度计划管理列表
     * 
     * @param schedule 调度计划管理
     * @return 调度计划管理集合
     */
    public List<Schedule> selectScheduleList(Schedule schedule);

    /**
     * 新增调度计划管理
     * 
     * @param schedule 调度计划管理
     * @return 结果
     */
    public int insertSchedule(Schedule schedule);

    /**
     * 修改调度计划管理
     * 
     * @param schedule 调度计划管理
     * @return 结果
     */
    public int updateSchedule(Schedule schedule);

    /**
     * 批量删除调度计划管理
     * 
     * @param scheduleIds 需要删除的调度计划管理主键集合
     * @return 结果
     */
    public int deleteScheduleByScheduleIds(Long[] scheduleIds);

    /**
     * 删除调度计划管理信息
     * 
     * @param scheduleId 调度计划管理主键
     * @return 结果
     */
    public int deleteScheduleByScheduleId(Long scheduleId);
}
